library(rvle)
source(paste(sep="", Sys.getenv("VLE_HOME"), "/vle-2001/pkgs/vle.recursive/R/vle.recursive.R"))

library(rvle)
f = vle.recursive.init(pkg="WACSgen", file="WACSgen.vpz")

vle.recursive.configSimulation(f,  config_parallel_type="threads",    
                               config_parallel_rm_files=F,
                               config_parallel_nb_slots=1,
                               working_dir="/tmp/",
                               expe_seed=1236,
                               expe_log=0);

vle.recursive.configPropagate(f, propagate = "simulation_engine.duration", value = 6574)


vle.recursive.configOutput(f, id="rain", 
                           path="view/WACSgen:Auzeville.rain",
                           integration="all", aggregation_input="all")
vle.recursive.configOutput(f, id="tmin", 
                           path="view/WACSgen:Auzeville.tmin",
                           integration="all", aggregation_input="all")
vle.recursive.configOutput(f, id="tmax", 
                           path="view/WACSgen:Auzeville.tmax",
                           integration="all", aggregation_input="all")
vle.recursive.configOutput(f, id="RG", 
                           path="view/WACSgen:Auzeville.RG",
                           integration="all", aggregation_input="all")
vle.recursive.configOutput(f, id="ETPP", 
                           path="view/WACSgen:Auzeville.ETPP",
                           integration="all", aggregation_input="all")
vle.recursive.configOutput(f, id="month",
                           path="view/WACSgen:Auzeville.month",
                           integration="all", aggregation_input="all")


res = vle.recursive.simulate(f, withSpawn=1)

vars = c("tmin", "tmax", "RG", "rain", "ETPP")
sd =NULL;
mean =NULL;

for (var in vars) {
  mean_var =  unlist(lapply(1:12, function(month) {
    mean(res[[var]][which(res$month[,1] == month)])
  }));
  sd_var =  unlist(lapply(1:12, function(month) {
    sd(res[[var]][which(res$month[,1] == month)])
  }));
  sd = rbind(sd, sd_var);
  mean = rbind(mean, mean_var);
}
rownames(mean) <- vars;
rownames(sd) <- vars;
for_record_mean = data.frame(mean);
for_record_sd = data.frame(sd);

# >
# > for_record_mean
# X1         X2          X3          X4          X5          X6
# tmin   2.8346391   2.547669    4.607011    7.649869   11.162393   14.289798
# tmax  10.2099738  11.126714   14.633440   18.422914   22.393547   25.746352
# RG   531.4792931 846.728057 1336.414250 1721.734828 2070.836317 2338.184473
# rain   1.7629098   1.506178    2.072559    2.253644    1.902131    1.596452
# ETPP   0.4136818   1.021794    2.078375    3.087142    4.061498    5.082104
# X7          X8          X9         X10         X11         X12
# tmin   16.372100   15.760411   13.544279    9.927857   6.1835347   3.5480133
# tmax   28.440001   28.466551   24.995445   20.013719  14.0571860  10.2906401
# RG   2255.189993 2076.959897 1552.759053 1044.383780 596.9619506 443.1294369
# rain    1.313922    1.061461    1.699584    1.535314   2.8063767   1.5564959
# ETPP    5.113955    4.652204    3.174898    1.827663   0.7188916   0.2977577
# > for_record_sd
# X1          X2          X3         X4         X5         X6
# tmin   4.1887904   4.2776589   3.9642743   3.280659   2.996589   3.028650
# tmax   4.1769323   4.2850960   4.2568087   3.946648   4.405124   4.366108
# RG   239.9696309 362.7665781 573.2778845 698.155180 774.739596 748.418923
# rain   4.3587559   3.7192903   5.8300667   5.765416   4.995979   5.102969
# ETPP   0.2872842   0.4823804   0.9048904   1.101750   1.422716   1.513362
# X7         X8          X9         X10         X11         X12
# tmin   3.016421   3.251433   4.0568833   4.1694254   4.5365753   4.5008351
# tmax   4.435253   3.846645   3.6090418   4.1401720   4.1160834   4.3977016
# RG   704.869762 564.570450 481.5354196 415.8469462 294.7736157 212.6341728
# rain   3.950613   4.312208   4.4802045   3.7642696   7.1619107   3.8121717
# ETPP   1.452228   1.155519   0.9824735   0.7317535   0.4698335   0.2783773
# > 

par(mfrow=c(3,2))
for (var in vars) {
  mean_tmp= as.numeric(for_record_mean[var, ]);
  sd_tmp= as.numeric(for_record_sd[var, ]);
  
  plot(mean_tmp, type='l', col='red', ylab=var, 
      ylim = c(min(mean_tmp-sd_tmp),max(mean_tmp+sd_tmp)))
  lines(mean_tmp-sd_tmp)
  lines(mean_tmp+sd_tmp)
}

testInf = function(name = NULL, expect = NULL, got = NULL)
{
    mess = NULL;
    if (got < expect) {
        mess = paste("test '", sep ="", name);
        mess = paste(mess, sep ="", "'=> ok (got < expect): ");
        mess = paste(mess, got);
        mess = paste(mess, "<");
        mess = paste(mess, expect);
    } else {
        mess = paste("test '", sep ="", name);
        mess = paste(mess, sep ="", "'=> ERROR (got < expect):");
        mess = paste(mess, got);
        mess = paste(mess, "<");
        mess = paste(mess, expect);
    }
    print(mess);
}

testInf(name="auzeville_95_12_tmin", expect=0.001, got=abs(mean(res$tmin) - 9.069005))
testInf(name="auzeville_95_12_tmax", expect=0.001, got=abs(mean(res$tmax) - 19.10551))
testInf(name="auzeville_95_12_RG", expect=0.001, got=abs(mean(res$RG) - 1403.636))
testInf(name="auzeville_95_12_rain", expect=0.001, got=abs(mean(res$rain) - 1.7541))
testInf(name="auzeville_95_12_ETPP", expect=0.001, got=abs(mean(res$ETPP) - 2.635129))



